--[[
****************************************************************************************

ARLFrame.lua

Frame functions for all of AckisRecipeList

$Date: 2008-05-20 20:57:31 -0400 (Tue, 20 May 2008) $
$Rev: 74607 $

****************************************************************************************
]]--

local L			= LibStub("AceLocale-3.0"):GetLocale("AckisRecipeList")
local Crayon	= LibStub("LibCrayon-3.0")

local addon = AckisRecipeList

-- Prototype: http://i30.tinypic.com/2hoxncl.jpg
-- I want to turn the GUI into that, but prettier... most functionality is in already, all the tables etc are created, just need to actually use the information now.

-- Calculates the total height of all the recipes in the child frame

local function CalculateChildHeight()

	local tempheight = 0
	local RecipeFrame = AckisRecipeListRecipe1

	while (RecipeFrame ~= nil) do
		tempheight = RecipeFrame:GetHeight() + RecipeFrame.RecipeAquireText:GetHeight() + tempheight
		RecipeFrame = RecipeFrame.NextRecipe
	end

	return tempheight

end

-- Adds recipe text info to the frames
-- Function to run when the + is clicked in the frame.  Will expand the recipe name and print out how to obtain it.

local function OnClickExpandRecipe()

	if (this.IsPushed == false) then
		local RecipeText = nil

		local sorttype = addon.db.profile.sorting

		if (sorttype == "Skill") or (sorttype == "Aquisition") then
			RecipeText = string.match(this:GetText(), "|c.*%[.*%]|r %- (.*)")
		elseif (sorttype == "Name") then
			RecipeText = string.match(this:GetText(), "(.*) %- |c.*%[.*%]|r")
		end

		-- Changed the graphic of the + to a -
		this:SetNormalTexture("Interface\\Buttons\\UI-MinusButton-Up")
		this:SetPushedTexture("Interface\\Buttons\\UI-MinusButton-Down")
		this:SetHighlightTexture("Interface\\Buttons\\UI-MinusButton-Hilight")

		-- Keep track of button state
		this.IsPushed = true

		-- Show expanded text
		if (addon.MissingRecipeListing[RecipeText] == nil) then
			this.RecipeAquireText:SetText(L["Unknown"])
		else
			this.RecipeAquireText:SetText("    - " .. addon.MissingRecipeListing[RecipeText]["Acquire"])
		end

		this.RecipeAquireText:SetWidth(300)

		this.RecipeAquireText:Show()

		-- Reposition the next recipe entry
		if (this.NextRecipe ~= nil) then
			this.NextRecipe:ClearAllPoints()
			this.NextRecipe:SetPoint("TOPLEFT", this.RecipeAquireText, "BOTTOMLEFT", -20, -5)
		end

	else

		-- Changed the graphic of the - to a +
		this:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
		this:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
		this:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")

		-- Keep track of button state
		this.IsPushed = false

		-- Hide expanded text
		this.RecipeAquireText:SetText("")
		this.RecipeAquireText:Hide()

		-- Reposition the next recipe entry
		if (this.NextRecipe ~= nil) then
			this.NextRecipe:ClearAllPoints()
			this.NextRecipe:SetPoint("TOPLEFT", this, "BOTTOMLEFT", 0, 0)
		end
	end

	addon.Frame.ScrollFrame:UpdateScrollChildRect()

end

-- Adds recipe text info to the frames

local function AddRecipeInfo(CurrentProfession, CurrentProfessionLevel, SortedList, CurrentSpeciality)

	local OldFrame = nil
	local RecipeFrame = nil
	local RecipeCount = 1
	
	for i, RecipeName in ipairs(SortedList) do

		if (addon:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentProfession, CurrentSpeciality)) then

			-- If the frame isn't created, then create it and set the parameters for it, otherwise use the current frame (recycle it)
			if (not _G["AckisRecipeListRecipe" .. RecipeCount]) then
				RecipeFrame = CreateFrame("Button", "AckisRecipeListRecipe" .. RecipeCount, addon.Frame.ScrollChild, "ClassTrainerSkillButtonTemplate")
				RecipeFrame:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
				RecipeFrame:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
				RecipeFrame:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")
				RecipeFrame:SetTextColor(1, 1, 1)
				RecipeFrame:SetWidth(18)
				RecipeFrame:SetScript("OnClick",
											OnClickExpandRecipe
									)
				RecipeFrame:SetScript("OnLeave", function()
											GameTooltip:Hide()
										end
							)
				RecipeFrame.IsPushed = false

				-- Create aquire text for the recipe
				RecipeFrame.RecipeAquireText = RecipeFrame:CreateFontString("AckisRecipeListRecipe" .. RecipeCount .. "Text", "DIALOG")

				RecipeFrame.RecipeAquireText:ClearAllPoints()
				RecipeFrame.RecipeAquireText:SetPoint("TOPLEFT", RecipeFrame, "BOTTOMLEFT", 20, 0)
				RecipeFrame.RecipeAquireText:SetFontObject("GameFontNormalSmall")
				RecipeFrame.RecipeAquireText:SetTextColor(1, 1, 1)
				RecipeFrame.RecipeAquireText:SetJustifyH("LEFT")

			else

				-- Grab the frame from the global stack
				RecipeFrame = _G["AckisRecipeListRecipe" .. RecipeCount]

			end

			-- If we have a previous recipe, set the previous recipe next recipe to this current recipe
			if (OldFrame ~= nil) then
				OldFrame.NextRecipe = RecipeFrame
			end

			-- If we're at the last recipe, set the next reicpe to nil, otherwise set the previous entries nextrecipe to a temp variable.
			local NumMissingRecipes = addon.NumberOfRecipes - addon.FoundRecipes
			if (i == NumMissingRecipes) then
				RecipeFrame.NextRecipe = nil
			else
				OldFrame = RecipeFrame
			end

			RecipeFrame:ClearAllPoints()

			-- If we're on the first recipe, set the points in relation to the main frame, otherwise set them in relation to the previous recipe
			if (RecipeCount == 1) then
				--RecipeFrame:SetPoint("TOPLEFT", addon.Frame.ScrollChild, "TOPLEFT", 5, -30)
				RecipeFrame:SetPoint("TOPLEFT",addon.Frame.ScrollChild,"TOPLEFT",5,0)
			else
				RecipeFrame:SetPoint("TOPLEFT", "AckisRecipeListRecipe" .. (RecipeCount - 1), "BOTTOMLEFT", 0, -1)
			end

			local temprecipetext

			local sorttype = addon.db.profile.sorting

			if (sorttype == "Skill") or (sorttype == "Aquisition") then
				if (addon.MissingRecipeListing[RecipeName]["Level"] > CurrentProfessionLevel) then
					temprecipetext = Crayon:Red("[" .. addon.MissingRecipeListing[RecipeName]["Level"] .. "]") .. " - " .. RecipeName
				else
					temprecipetext = Crayon:White("[" .. addon.MissingRecipeListing[RecipeName]["Level"] .. "]") .. " - " .. RecipeName
				end
			elseif (sorttype == "Name") then
				if (addon.MissingRecipeListing[RecipeName]["Level"] > CurrentProfessionLevel) then
					temprecipetext = RecipeName .. " - " .. Crayon:Red("[" .. addon.MissingRecipeListing[RecipeName]["Level"] .. "]")
				else
					temprecipetext = RecipeName .. " - " .. Crayon:White("[" .. addon.MissingRecipeListing[RecipeName]["Level"] .. "]")
				end
			end

			RecipeFrame:SetText(temprecipetext)
			RecipeFrame:SetScript("OnEnter", function(this)
					GameTooltip_SetDefaultAnchor(GameTooltip, this)
					GameTooltip:SetText(temprecipetext .. addon.br .. addon.MissingRecipeListing[RecipeName]["Acquire"])
					GameTooltip:Show()
				end
			)

			RecipeFrame:Show()
			RecipeCount = RecipeCount + 1
		end
	end
end

-- Closes the frame and cleans sets everything that was displayed to nil

function addon:CloseWindow()

	-- Clean up recipe entries
	local RecipeFrame = AckisRecipeListRecipe1

	-- Clear x number of entries for all missing recipes
	while (RecipeFrame ~= nil) do
		RecipeFrame.RecipeAquireText:SetText("")
		RecipeFrame.RecipeAquireText:Hide()

		RecipeFrame:SetText("")
		RecipeFrame:Hide()

		if (RecipeFrame.IsPushed == true) then
			RecipeFrame:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
			RecipeFrame:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
			RecipeFrame:SetDisabledTexture("Interface\\Buttons\\UI-PlusButton-Disabled")
			RecipeFrame:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")
			RecipeFrame.IsPushed = false
		end

		RecipeFrame.RecipeAquireText:SetText("")
		RecipeFrame.RecipeAquireText:Hide()
		RecipeFrame = RecipeFrame.NextRecipe
	end

	addon.Frame:Hide()

	addon.ResetOkayARL = true

	if (addon.ResetOkayBlizz and addon.ResetOkayARL) then
		addon:ResetVariables()
	end

end

-- Expands all the headers

function addon:ExpandAll()

	local frame = _G["AckisRecipeListRecipe1"]

	while (frame) do
		if (frame:IsShown() ~= nil) then
			if (frame.IsPushed == false) then
				frame:Click()
			end
		end
		frame = frame.NextRecipe
	end

end

-- Closes all the headers

function addon:CloseAll()

	local frame = _G["AckisRecipeListRecipe1"]

	while (frame) do
		if (frame:IsShown() ~= nil) then
			if (frame.IsPushed == true) then
				frame:Click()
			end
		end
		frame = frame.NextRecipe
	end

end

-- Create the scan button and add it to Skillet if applicable

function addon:CreateScanButton()
	-- Create the scan button
	if (not addon.ScanButton) then
		addon.ScanButton = CreateFrame("Button","addon.ScanButton",UIParent,"UIPanelButtonTemplate")
	end

	-- Add to Skillet interface
	if (Skillet and Skillet:IsActive()) then
		addon.ScanButton:SetParent(SkilletFrame)
		addon.ScanButton:Show()
		addon.ScanButton:SetTextColor(1, 0.8, 0)
		Skillet:AddButtonToTradeskillWindow(addon.ScanButton)
		addon.ScanButton:SetWidth(80)
	end

	-- Set some of the common button properties
	addon.ScanButton:SetHeight(20)
	addon.ScanButton:RegisterForClicks("LeftButtonUp")
	addon.ScanButton:SetScript("OnClick", function()
											addon:ToggleFrame()
										end
							)
	addon.ScanButton:SetScript("OnEnter", function(this)
											GameTooltip_SetDefaultAnchor(GameTooltip, this)
											GameTooltip:SetText(L["Scan Skills Long"])
											GameTooltip:Show()
										end
							)
	addon.ScanButton:SetScript("OnLeave", function()
											GameTooltip:Hide()
										end
							)
	addon.ScanButton:SetText(L["ScanButton"])
	addon.ScanButton:Enable()
end

-- Adds a button to the trade skill/skillet/crafting skill window allowing you to scan

function addon:ShowScanButton()
	-- Add to Fizzwidget Hunter's Helper
	if (FHH_UI and CraftIsPetTraining()) then
		addon.ScanButton:SetParent(FHH_UI)
		addon.ScanButton:ClearAllPoints()
		addon.ScanButton:SetPoint("RIGHT",FHH_UICloseButton,"LEFT",10,0)
		addon.ScanButton:SetTextColor(1, 1, 0)
		addon.ScanButton:SetWidth(addon.ScanButton:GetTextWidth() + 10)
	-- Add to ATSW
	elseif (ATSWFrame and not CraftIsPetTraining()) then
		addon.ScanButton:SetParent(ATSWFrame)
		addon.ScanButton:ClearAllPoints()
		addon.ScanButton:SetPoint("RIGHT", ATSWOptionsButton, "LEFT", 0, 0)
		addon.ScanButton:SetTextColor(ATSWOptionsButton:GetTextColor())
		addon.ScanButton:SetHeight(ATSWOptionsButton:GetHeight())
		addon.ScanButton:SetWidth(80)
	elseif (addon.SkillType == "Trade") then
	-- Anchor to trade window
		addon.ScanButton:SetParent(TradeSkillFrame)
		addon.ScanButton:ClearAllPoints()
		addon.ScanButton:SetPoint("RIGHT",TradeSkillFrameCloseButton,"LEFT",10,0)
		addon.ScanButton:SetTextColor(1, 1, 0)
		addon.ScanButton:SetWidth(addon.ScanButton:GetTextWidth() + 10)
	-- Anchor to crafting window
	elseif (addon.SkillType == "Craft") then
		addon.ScanButton:SetParent(CraftFrame)
		addon.ScanButton:ClearAllPoints()
		addon.ScanButton:SetPoint("RIGHT",CraftFrameCloseButton,"LEFT",10,0)
		addon.ScanButton:SetTextColor(1, 1, 0)
		addon.ScanButton:SetWidth(addon.ScanButton:GetTextWidth() + 10)
	end
	addon.ScanButton:SetFrameStrata("DIALOG")
	addon.ScanButton:Show()
end

-- Allows the scan button to close the scan window

function addon:ToggleFrame()
	if (addon.Frame and addon.Frame:IsVisible()) then
		addon.Frame:Hide()
	else
		addon:AckisRecipeList_Command()
	end
end

-- Creates the initial frame to display recipes into

function addon:CreateFrame(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

	addon.ResetOkayARL = false

	-- Normal GUI
	if (not addon.db.profile.testgui) then

	if (not addon.Frame) then

		-- Create the main frame
		addon.Frame = CreateFrame("Frame", "addon.Frame", UIParent)
		--Allows ARL to be closed with the Escape key
		tinsert(UISpecialFrames, "addon.Frame")

		addon.Frame:SetWidth(384)
		addon.Frame:SetHeight(430)
		addon.Frame:SetBackdrop(
		{
			bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background",
			edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border",
			tile="false",
			edgeSize = 16,
			insets = {
						left = 5,
						right = 5,
						top = 5,
						bottom = 5
					}
		})
		addon.Frame:SetBackdropColor(0, 0, 0)
		addon.Frame:EnableMouse(true)
		addon.Frame:EnableKeyboard(true)
		addon.Frame:SetMovable(true)
		addon.Frame:SetScript("OnMouseDown", function() addon.Frame:StartMoving() end)
		addon.Frame:SetScript("OnHide", function() self:CloseWindow()	end)
		addon.Frame:SetScript("OnMouseUp", function()	addon.Frame:StopMovingOrSizing() end)

		-- ATSW for some reason has a window "bigger" than what you can see
		if (ATSWFrame and not CraftIsPetTraining()) then
			addon.Frame:SetFrameStrata("DIALOG")
		end

		-- Add header frame
		addon.Frame.Header = CreateFrame("Frame", "addon.Frame.Header", addon.Frame)

		addon.Frame.Header:SetWidth(192)
		addon.Frame.Header:SetHeight(32)
		addon.Frame.Header:ClearAllPoints()
		addon.Frame.Header:SetPoint("TOP", addon.Frame, "TOP", 0, 6)
		addon.Frame.Header:EnableMouse(true)
		addon.Frame.Header:SetMovable(true)
		addon.Frame.Header:SetScript("OnMouseDown", function()
														addon.Frame:StartMoving()
													end
									)
		addon.Frame.Header:SetScript("OnMouseUp", function()
													addon.Frame:StopMovingOrSizing()
												end
									)

		-- Add texture to the header frame
		addon.Frame.Header.Texture = addon.Frame.Header:CreateTexture("addon.Frame.Header.Texture", "ARTWORK")

		addon.Frame.Header.Texture:SetTexture("Interface\\DialogFrame\\UI-DialogBox-Header")
		addon.Frame.Header.Texture:SetWidth(384)
		addon.Frame.Header.Texture:SetHeight(64)
		addon.Frame.Header.Texture:ClearAllPoints()
		addon.Frame.Header.Texture:SetPoint("TOP", addon.Frame.Header, "TOP", 0, 5)

		-- Add text to header frame
		addon.Frame.Header.Text = addon.Frame.Header:CreateFontString("addon.Frame.Header.Text", "ARTWORK")

		addon.Frame.Header.Text:SetFontObject(GameFontNormal)
		addon.Frame.Header.Text:ClearAllPoints()
		addon.Frame.Header.Text:SetPoint("CENTER", addon.Frame.Header, "CENTER", 0, 0)
		addon.Frame.Header.Text:SetText(addon.ARLTitle)

		-- Add close button
		addon.Frame.CloseButton = CreateFrame("Button","addon.Frame.CloseButton",addon.Frame,"UIPanelButtonTemplate")

		addon.Frame.CloseButton:SetWidth(100)
		addon.Frame.CloseButton:SetHeight(24)
		addon.Frame.CloseButton:ClearAllPoints()
		addon.Frame.CloseButton:SetPoint("BOTTOMRIGHT", addon.Frame, -10, 10)
		addon.Frame.CloseButton:RegisterForClicks("LeftButtonUp")
		addon.Frame.CloseButton:SetScript("OnClick", function() self:CloseWindow() end)
		addon.Frame.CloseButton:SetScript("OnEnter", function(this)
												GameTooltip_SetDefaultAnchor(GameTooltip, this)
												GameTooltip:SetText(L["Close Window"])
												GameTooltip:Show()
											end
										)
		addon.Frame.CloseButton:SetScript("OnLeave", function() GameTooltip:Hide() end)
		addon.Frame.CloseButton:SetFont("GameFontHighlightSmall",12)
		addon.Frame.CloseButton:SetTextColor(1, 1, 1)
		addon.Frame.CloseButton:SetText(L["Close"])
		addon.Frame.CloseButton:Enable()

		-- Add expand all button
		addon.Frame.ExpandAllButton = CreateFrame("Button","addon.Frame.ExpandAllButton",addon.Frame,"UIPanelButtonTemplate")

		addon.Frame.ExpandAllButton:SetWidth(16)
		addon.Frame.ExpandAllButton:SetHeight(16)
		addon.Frame.ExpandAllButton:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
		addon.Frame.ExpandAllButton:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
		addon.Frame.ExpandAllButton:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")
		addon.Frame.ExpandAllButton:ClearAllPoints()
		addon.Frame.ExpandAllButton:SetPoint("TOPRIGHT",addon.Frame,"TOPRIGHT",-10,-20)
		addon.Frame.ExpandAllButton:SetTextColor(1, 1, 1)
		addon.Frame.ExpandAllButton:SetScript("OnClick", function() self:ExpandAll() end)
		addon.Frame.ExpandAllButton:SetScript("OnEnter", function(this)
												GameTooltip_SetDefaultAnchor(GameTooltip, this)
												GameTooltip:SetText(L["Expand All"])
												GameTooltip:Show()
											end
										)
		addon.Frame.ExpandAllButton:SetScript("OnLeave", function() GameTooltip:Hide() end)
		addon.Frame.ExpandAllButton:Enable()

		-- Add collaspse all button
		addon.Frame.CollapseAllButton = CreateFrame("Button","addon.Frame.CollapseAllButton",addon.Frame,"UIPanelButtonTemplate")

		addon.Frame.CollapseAllButton:SetWidth(16)
		addon.Frame.CollapseAllButton:SetHeight(16)
		addon.Frame.CollapseAllButton:SetNormalTexture("Interface\\Buttons\\UI-MinusButton-Up")
		addon.Frame.CollapseAllButton:SetPushedTexture("Interface\\Buttons\\UI-MinusButton-Down")
		addon.Frame.CollapseAllButton:SetHighlightTexture("Interface\\Buttons\\UI-MinusButton-Hilight")
		addon.Frame.CollapseAllButton:ClearAllPoints()
		addon.Frame.CollapseAllButton:SetPoint("TOPRIGHT",addon.Frame,"TOPRIGHT",-30,-20)
		addon.Frame.CollapseAllButton:SetTextColor(1, 1, 1)
		addon.Frame.CollapseAllButton:SetScript("OnClick", function() self:CloseAll() end)
		addon.Frame.CollapseAllButton:SetScript("OnEnter", function(this)
												GameTooltip_SetDefaultAnchor(GameTooltip, this)
												GameTooltip:SetText(L["Collapse All"])
												GameTooltip:Show()
											end
										)
		addon.Frame.CollapseAllButton:SetScript("OnLeave", function() GameTooltip:Hide() end)
		addon.Frame.CollapseAllButton:Enable()

		-- Add a "close with x" button
		addon.Frame.XButton = CreateFrame("Button","addon.Frame.XButton",addon.Frame,"UIPanelCloseButton")

		addon.Frame.XButton:ClearAllPoints()
		addon.Frame.XButton:SetPoint("TOPRIGHT",addon.Frame,"TOPRIGHT",0,0)
		addon.Frame.XButton:RegisterForClicks("LeftButtonUp")
		addon.Frame.XButton:SetScript("OnClick", function() self:CloseWindow() end)
		addon.Frame.XButton:SetScript("OnEnter", function(this)
												GameTooltip_SetDefaultAnchor(GameTooltip, this)
												GameTooltip:SetText(L["Close Window"])
												GameTooltip:Show()
											end
										)
		addon.Frame.XButton:SetScript("OnLeave", function() GameTooltip:Hide() end)
		addon.Frame.XButton:Enable()

		-- Adds scroll frame to mainframe
		addon.Frame.ScrollFrame = CreateFrame("ScrollFrame", "addon.Frame.ScrollFrame", addon.Frame, "UIPanelScrollFrameTemplate")
	
		addon.Frame.ScrollFrame:ClearAllPoints()
		addon.Frame.ScrollFrame:SetPoint("TOPLEFT", addon.Frame, "TOPLEFT", 10, -50)
		addon.Frame.ScrollFrame:SetHeight(345)
		addon.Frame.ScrollFrame:SetWidth(344)
		addon.Frame.ScrollFrame:EnableMouseWheel(true)
		addon.Frame.ScrollFrame:EnableMouse(true)

		addon.Frame.ScrollChild = CreateFrame("Frame", "addon.Frame.ScrollChild", addon.Frame.ScrollFrame)

		addon.Frame.ScrollChild:ClearAllPoints()
		addon.Frame.ScrollChild:SetPoint("TOPLEFT", addon.Frame.ScrollFrame, "TOPLEFT", 10, -30)
		addon.Frame.ScrollChild:SetWidth(340)
		addon.Frame.ScrollChild:SetHeight(355)
		addon.Frame.ScrollChild:EnableMouseWheel(true)
		addon.Frame.ScrollChild:EnableMouse(true)

		addon.Frame.ScrollFrame:SetScrollChild(addon.Frame.ScrollChild)

		-- Add progress bar to frame
		addon.Frame.ProgressBar = CreateFrame("StatusBar", "addon.Frame.ProgressBar", addon.Frame)
		
		addon.Frame.ProgressBar:SetWidth(260)
		addon.Frame.ProgressBar:SetHeight(20)
		addon.Frame.ProgressBar:ClearAllPoints()
		addon.Frame.ProgressBar:SetPoint("BOTTOMLEFT", addon.Frame, 10, 10)
		addon.Frame.ProgressBar:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
		addon.Frame.ProgressBar:SetOrientation("HORIZONTAL")
		addon.Frame.ProgressBar:SetStatusBarColor(0.25, 0.25, 0.75)

		addon.Frame.ProgressBarBorder = CreateFrame("Button", "addon.Frame.ProgressBarBorder", addon.Frame.ProgressBar)

		-- Add border to status bar
		addon.Frame.ProgressBarBorder:SetNormalTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-BarBorder")
		addon.Frame.ProgressBarBorder:SetWidth(270)
		addon.Frame.ProgressBarBorder:SetHeight(40)
		addon.Frame.ProgressBarBorder:ClearAllPoints()
		addon.Frame.ProgressBarBorder:SetPoint("CENTER", addon.Frame.ProgressBar, "CENTER", 0, 0)

		addon.Frame.ProgressBarText = addon.Frame.ProgressBar:CreateFontString("addon.Frame.ProgressBarText", "ARTWORK")

		-- Add text to header frame
		addon.Frame.ProgressBarText:SetFontObject(GameFontHighlightSmall)
		addon.Frame.ProgressBarText:ClearAllPoints()
		addon.Frame.ProgressBarText:SetPoint("CENTER", addon.Frame.ProgressBar, "CENTER", 0, 0)

		-- Adds Profession header text
		addon.Frame.ProfessionText = addon.Frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
		addon.Frame.ProfessionText:SetTextColor(1.0, 1.0, 0.1)
		addon.Frame.ProfessionText:ClearAllPoints()
		addon.Frame.ProfessionText:SetPoint("TOP", 0, -30)

	end

	addon.Frame:ClearAllPoints()

	-- Anchor the frame to a specific window

	-- Anchors to Skillet window
	if (Skillet and Skillet:IsActive() and not CraftIsPetTraining()) then
		addon.Frame:SetPoint("LEFT", SkilletFrame, "RIGHT", 0, 0)
	-- Anchor to Beast window if skillet is active
	elseif (Skillet and Skillet:IsActive() and CraftIsPetTraining()) then
		addon.Frame:SetPoint("RIGHT", CraftFrame, "RIGHT", 345, 30)
	-- Anchor to ATSW
	elseif (ATSWFrame) then
		addon.Frame:SetPoint("RIGHT", ATSWFrame, "RIGHT", 350, 25)
	-- Anchor to trade skill window
	elseif (addon.SkillType == "Trade") then
		addon.Frame:SetPoint("RIGHT", TradeSkillFrame, "RIGHT", 345, 30)
	-- Anchor to crafting window
	elseif (addon.SkillType == "Craft") then
		addon.Frame:SetPoint("RIGHT", CraftFrame, "RIGHT", 345, 30)
	-- Nothing found to anchor, just put it up in the middle
	else
		addon.Frame:SetPoint("CENTER", UIParent, "CENTER", 0, 0)
	end

	-- Set the text / status bar display  of the progress bar
	if (CurrentSpeciality == "") then
		addon.Frame.ProfessionText:SetText(CurrentProfession)
	else
		addon.Frame.ProfessionText:SetText(CurrentProfession .. " - " .. CurrentSpeciality)
	end

	addon.Frame:Show()

	-- Add frame elements
	AddRecipeInfo(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

	-- Include filtered recipes in overall count
	if (addon.db.profile.includefiltered) then
		addon.Frame.ProgressBar:SetMinMaxValues(0, addon.NumberOfRecipes)
		addon.Frame.ProgressBar:SetValue(addon.FoundRecipes)
		addon.Frame.ProgressBarText:SetText(addon.FoundRecipes .. " \\ " .. addon.NumberOfRecipes .. " - " .. math.floor(addon.FoundRecipes / addon.NumberOfRecipes * 100) .. "%")
	-- Do not include filtered recipes
	else
		addon.Frame.ProgressBar:SetMinMaxValues(0, addon.NumberOfRecipes - addon.FilteredRecipes)
		addon.Frame.ProgressBar:SetValue(addon.FoundRecipes)
		addon.Frame.ProgressBarText:SetText(addon.FoundRecipes .. " \\ " .. addon.NumberOfRecipes - addon.FilteredRecipes .. " - " .. math.floor(addon.FoundRecipes / (addon.NumberOfRecipes - addon.FilteredRecipes) * 100) .. "%")
	end

	-- New dev GUI
	else
		self:Print("Test purposes only")
		if (not addon.Frame) then

		-- Create the main frame
		addon.Frame = CreateFrame("Frame", "addon.Frame", UIParent)
		--Allows ARL to be closed with the Escape key
		tinsert(UISpecialFrames, "addon.Frame")

		addon.Frame:SetWidth(384)
		addon.Frame:SetHeight(430)
		addon.Frame:SetBackdrop(
		{
			bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background",
			edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border",
			tile="false",
			edgeSize = 16,
			insets = {
						left = 5,
						right = 5,
						top = 5,
						bottom = 5
					}
		})
		addon.Frame:SetBackdropColor(0, 0, 0)
		addon.Frame:EnableMouse(true)
		addon.Frame:EnableKeyboard(true)
		addon.Frame:SetMovable(true)
		addon.Frame:SetScript("OnMouseDown", function() addon.Frame:StartMoving() end)
		addon.Frame:SetScript("OnHide", function() self:CloseWindow()	end)
		addon.Frame:SetScript("OnMouseUp", function()	addon.Frame:StopMovingOrSizing() end)

		addon.Frame:ClearAllPoints()
		addon.Frame:SetPoint("CENTER", UIParent, "CENTER", 0, 0)
		addon.Frame:Show()

		end

	end

end

